@@ -35,10 +35,10 @@ Supported platforms: wxMSW and wxMAC natively, wxGTK by means of a
 workaround.
 
 Author: Frank Niessink <frank@niessink.com>
-Copyright 2006, Frank Niessink
+Copyright 2006, 2008, 2010, Frank Niessink
 License: wxWidgets license
-Version: 0.9
-Date: September 6, 2006
+Version: 1.1
+Date: August 1, 2010
 """
 
 import wx
@@ -189,8 +189,9 @@ class BasePopupFrame(wx.Frame):
 
     def OnKillFocus(self, event):
         # We hide the frame rather than destroy it, so it can be 
-        # popped up again later:
-        self.Hide()
+        # popped up again later. Use CallAfter so that clicking the combobox
+        # button doesn't immediately popup the frame again.     
+        wx.CallAfter(self.Hide)
         self.GetParent().NotifyNoItemSelected()
         event.Skip()
 
@@ -328,7 +329,10 @@ class BaseComboTreeBox(object):
     # Event handlers
 
     def OnMouseClick(self, event):
-        self.Popup()
+        if self._popupFrame.IsShown():
+            self.Hide()
+        else:
+            self.Popup()
         # Note that we don't call event.Skip() to prevent popping up the
         # ComboBox's own box.
 
@@ -362,12 +366,16 @@ class BaseComboTreeBox(object):
 
     def OnText(self, event):
         event.Skip()
-        item = self.FindString(self._text.GetValue())
-        if item:
-            if self._tree.GetSelection() != item:
+        textValue = self._text.GetValue()
+        selection = self._tree.GetSelection()
+        if not selection or self._tree.GetItemText(selection) != textValue:
+            # We need to change the selection because it doesn't match the
+            # text just entered
+            item = self.FindString(textValue)
+            if item:
                 self._tree.SelectItem(item)
-        else:
-            self._tree.Unselect()
+            else:
+                self._tree.Unselect()
 
     # Methods called by the PopupFrame, to let the ComboTreeBox know
     # about what the user did.
@@ -409,6 +417,14 @@ class BaseComboTreeBox(object):
         # to SetMinSize is needed to force a resize of the popupFrame: 
         self._popupFrame.SetMinSize((width, height)) 
         self._popupFrame.Show()
+        
+    def Hide(self):
+        """
+        Hide(self)
+        
+        Hide the popped up frame with the tree.
+        """
+        self._popupFrame.Hide()
  
     def GetTree(self):
         """
@@ -732,7 +748,7 @@ class MSWComboTreeBox(NativeComboTreeBox):
 
     def _keyShouldPopUpTree(self, keyEvent):
         return super(MSWComboTreeBox, self)._keyShouldPopUpTree(keyEvent) or \
-            (keyEvent.GetKeyCode() == wx.WXK_F4) or \
+            (keyEvent.GetKeyCode() == wx.WXK_F4 and not keyEvent.HasModifiers()) or \
             ((keyEvent.AltDown() or keyEvent.MetaDown()) and \
               keyEvent.GetKeyCode() == wx.WXK_UP)
 
